[FFmpeg-soc] [soc]: r4395 - seek_api/mpeg.c

spyfeng subversion at mplayerhq.hu
Mon Jun 8 16:20:05 CEST 2009


Author: spyfeng
Date: Mon Jun  8 16:20:05 2009
New Revision: 4395

Log:
typo fixed

Modified:
   seek_api/mpeg.c

Modified: seek_api/mpeg.c
==============================================================================
--- seek_api/mpeg.c	Mon Jun  8 16:18:20 2009	(r4394)
+++ seek_api/mpeg.c	Mon Jun  8 16:20:05 2009	(r4395)
@@ -597,7 +597,7 @@ static int64_t mpegps_read_dts(AVFormatC
     return dts;
 }
 
 /* 0 for sucess and -1 for error */
 static int find_keyframe(AVFormatContext *s, int64_t *ret_pos, int64_t *pts, int64_t target_ts, int flags)
 {
     AVPacket pkt1, *pkt = &pkt1;
@@ -652,7 +652,7 @@ static int mpegps_read_seek1(struct AVFo
     if (ts < 0) {
         pts = ts = 0;
         url_fseek(s->pb, 0, SEEK_SET);
-        goto sucess;
+        goto success;
     }
 
     if (st->discard >= AVDISCARD_ALL) {
@@ -672,11 +672,11 @@ static int mpegps_read_seek1(struct AVFo
             av_log(s, AV_LOG_DEBUG, "the seek pos = %"PRId64", pts  = %"PRId64", targe timestamp = %"PRId64"\n", pos, pts, ts);
 
             if (pts == ts) { // find the target timestamp
-                goto sucess;
+                goto success;
             } else { // seek around to get the keyframe, then seek there
                 if (find_keyframe(s, &pos,&pts,ts, flags) == 0) {
                     url_fseek(s->pb, pos, SEEK_SET);
-                    goto sucess;
+                    goto success;
                 } else {
                     av_update_cur_dts(s, st, pts);
                     return -1;
@@ -697,12 +697,12 @@ static int mpegps_read_seek1(struct AVFo
     if (find_keyframe(s, &pos, &ret_ts, ts, flags) == 0) {
         url_fseek(s->pb, pos, SEEK_SET);
         pts =  ret_ts;
-        goto sucess;
+        goto success;
     } else {
         av_update_cur_dts(s, st, ret_ts);
         return -1;
     }
-sucess:
+success:
     av_update_cur_dts(s, st, pts);
     return 0;
 }
@@ -597,7 +597,7 @@ static int64_t mpegps_read_dts(AVFormatC
 }
 
-/* 0 for sucess and -1 for error */
+/* 0 for success and -1 for error */
 static int find_keyframe(AVFormatContext *s, int64_t *ret_pos, int64_t *pts, int64_t target_ts, int flags)
 {


More information about the FFmpeg-soc mailing list